## Prerequisites

- Python: <a href="https://pypi.org/project/django-virtual-models" target="_blank"><img src="https://img.shields.io/pypi/pyversions/django-virtual-models.svg?color=%2334D058" alt="Supported Python versions"></a>
- Django >= 3.2

## How to install

To install Django Virtual Models, just do:

```bash
pip install django-virtual-models
```

Currently `django-virtual-models` depends on `djangorestframework`, but it's not mandatory to use it.

There's no need to add `django_virtual_models` to Django's `INSTALLED_APPS`.
